/*
 * AugmentedLexicon.java
 *
 * George Ferguson, ferguson@cs.rochester.edu, 14 May 2002
 * Time-stamp: <Thu May 22 15:33:35 EDT 2003 ferguson>
 */

import java.io.IOException;

/**
 * An AugmentedLexicon maps words onto constituents with features (ie.,
 * AugmentedConstituents).
 */
public class AugmentedLexicon extends Lexicon {
    /**
     * Add AugmentedConstituent to list of entries for word, creating the list
     * if necessary.
     * We override our parent's method for this operation in order to
     * ensure that only AugmentedConstituents are added to AugmentedLexicons.
     * We will throw a ClassCastException if the given object is not
     * a AugmentedConstituent. This is better than having it come up later
     * when we try to use the constituent.
     */
    public void add(Symbol word, Constituent constit) {
	super.add(word, (AugmentedConstituent)constit);
    }
    /**
     * Read the given filename and augment this AugmentedLexicon.
     * @see AugmentedLexiconFileHandler
     */
    public void readFile(String filename) throws IOException {
	new AugmentedLexiconFileHandler(this).readFile(filename);
    }
}
