/*
 * GrammarRule.java
 *
 * George Ferguson, ferguson@cs.rochester.edu, 25 Apr 2002
 * Time-stamp: <Wed May 14 12:28:41 EDT 2003 ferguson>
 */

import java.util.Iterator;
import java.util.List;
import java.util.NoSuchElementException;

/**
 * A GrammarRule consists of a left-hand side (a single Constituent, the
 * ``product'' or ``mother'' of the rule), and a right-hand side (a list of
 * Constituents, the ``preconditions'' or ``daughters'' of the rule).
 * GrammarRules also have an id for use in tracing, etc.
 */
public class GrammarRule {
    /**
     * The id of this GrammarRule.
     */
    Symbol id;
    /**
     * The left-hand side of this GrammarRule.
     */
    Constituent lhs;
    /**
     * The right-hand side of this GrammarRule.
     */
    List rhs;
    /**
     * Create a new GrammarRule with given parameters.
     */
    public GrammarRule(Symbol id, Constituent lhs, List rhs) {
	this.id = id;
	this.lhs = lhs;
	this.rhs = rhs;
    }
    /**
     * Return the id of this GrammarRule.
     */
    public Symbol getId() {
	return id;
    }
    /**
     * Return the left-hand side of this GrammarRule (a Constituent).
     */
    public Constituent getLhs() {
	return lhs;
    }
    /**
     * Return the right-hand side of this GrammarRule (a List of Constituents).
     */
    public List getRhs() {
	return rhs;
    }
    /**
     * Returns the printable representation of this GrammarRule.
     */
    public String toString() {
	return toString(-1);
    }
    /**
     * Returns the printable representation of this GrammarRule with
     * the ``index'' marker at position NEXT of the rhs.
     */
    public String toString(int next) {
	StringBuffer buf = new StringBuffer("");
	Iterator elts = rhs.iterator();
	int i = 0;
	try {
	    while (elts.hasNext()) {
		buf.append(elts.next().toString());
		i += 1;
		if (i == next) {
		    buf.append(" *");
		}
		if (elts.hasNext()) {
		    buf.append(" ");
		}
	    }
	} catch (NoSuchElementException ex) {
	}
	return id.toString() + ": " + lhs.toString() + " <- " + buf.toString();
    }
}
