/*
 * HeadFeaturedConstituent.java
 *
 * George Ferguson, ferguson@cs.rochester.edu, 25 Apr 2002
 * Time-stamp: <Wed May 14 12:38:51 EDT 2003 ferguson>
 */

/**
 * An HeadFeaturedConstituent of a parse represents a syntactic element
 * augmented with feature information.
 * It consists of:
 * <UL>
 * <LI>the syntactic category
 * <LI>a set of features
 * <LI>a binary flag that indicates if the constituent is the head of a rule
 * </UL>
 * <P>
 * Note we don't override copyWithBindings() in this class.
 * That's because the head feature is irrelevent once we're processing
 * with the chart parser (but it might be confusing to see constituents
 * lose their HEAD marker). And if the HEAD marker was needed in later
 * stages, then we'd need to preserve it by overiding the copy method.
 */
public class HeadFeaturedConstituent extends AugmentedConstituent {
    /**
     * Flag true if this AugmentedConstituent is the head of a rule.
     */
    boolean head;
    /**
     * Returns true if this AugmentedConstituent is the head of a rule.
     */
    public boolean isHead() {
	return head;
    }
    /**
     * Create a new HeadFeaturedConstituent with the given attributes.
     */
    public HeadFeaturedConstituent(Symbol category, FeatureSet feats, boolean head) {
	super(category, feats);
	this.head = head;
    }
    /**
     * Create a new HeadFeaturedConstituent with the given attributes (and not
     * a head constituent).
     */
    public HeadFeaturedConstituent(Symbol category, FeatureSet feats) {
	this(category, feats, false);
    }
    /**
     * Returns the printable representation of this HeadFeaturedConstituent as a
     * String.
     */
    public String toString() {
	return "(" + category.toString() + (head ? "/HEAD" : "") + (features.isEmpty() ? "" : (" " + features.toString())) + ")";
    }
}
