/*
 * Test.java
 *
 * George Ferguson, ferguson@cs.rochester.edu, 24 Apr 2002
 * Time-stamp: <Thu Apr 25 10:30:14 EDT 2002 ferguson>
 */

/*
 * Set of tests for the unify package.
 */
public class Test {
    public static void main(String[] argv) {
	Unifiable x, y;

	System.out.println("Identical Symbols -> succeed with no bindings");
	x = Symbol.intern("A");
	y = x;
	test(x, y);

	System.out.println("Different Symbols -> fail");
	y = Symbol.intern("B");
	test(x, y);

	System.out.println("Variable (unconstrained) and Symbol -> bind var to sym");
	x = Symbol.intern("A");
	y = new Variable(Symbol.intern("Y"));
	test(x, y);

	System.out.println("Variable (constrained with sym in constraint) and Symbol -> bind var to sym");
	VariableValueSet constraints = new VariableValueSet();
	y = new Variable(Symbol.intern("Y"), constraints);
	constraints.clear();
	constraints.add(Symbol.intern("A"));
	constraints.add(Symbol.intern("B"));
	constraints.add(Symbol.intern("C"));
	test(x, y);

	System.out.println("Variable (constrained without sym) and Symbol -> fail");
	constraints.clear();
	constraints.add(Symbol.intern("D"));
	constraints.add(Symbol.intern("E"));
	constraints.add(Symbol.intern("F"));
	test(x, y);

	System.out.println("Two constrained vars with no intersection -> fail");
	constraints.clear();
	constraints.add(Symbol.intern("A"));
	constraints.add(Symbol.intern("B"));
	constraints.add(Symbol.intern("C"));
	x = new Variable(Symbol.intern("X"), constraints);
	VariableValueSet constraints2 = new VariableValueSet();
	constraints2.add(Symbol.intern("D"));
	constraints2.add(Symbol.intern("E"));
	constraints2.add(Symbol.intern("F"));
	y = new Variable(Symbol.intern("Y"), constraints2);
	test(x, y);

	System.out.println("Two constrained vars with unit intersection -> bind vars to sym");
	constraints.clear();
	constraints.add(Symbol.intern("A"));
	constraints.add(Symbol.intern("B"));
	constraints.add(Symbol.intern("C"));
	x = new Variable(Symbol.intern("X"), constraints);
	constraints2.clear();
	constraints2.add(Symbol.intern("D"));
	constraints2.add(Symbol.intern("B"));
	constraints2.add(Symbol.intern("F"));
	y = new Variable(Symbol.intern("Y"), constraints2);
	test(x, y);

	System.out.println("Two constrained vars with intersection -> bind both to new var");
	constraints.clear();
	constraints.add(Symbol.intern("A"));
	constraints.add(Symbol.intern("B"));
	constraints.add(Symbol.intern("C"));
	x = new Variable(Symbol.intern("X"), constraints);
	constraints2.clear();
	constraints2.add(Symbol.intern("A"));
	constraints2.add(Symbol.intern("Z"));
	constraints2.add(Symbol.intern("B"));
	y = new Variable(Symbol.intern("Y"), constraints2);
	test(x, y);

	System.out.println("Variable and Expression (not using var) -> bind var to expr");
	x = new Variable(Symbol.intern("X"));
	Expression e = new Expression();
	e.add(Symbol.intern("P"));
	e.add(Symbol.intern("A"));
	e.add(Symbol.intern("B"));
	test(x, e);

	System.out.println("Variable and nested Expression (not using var) -> bind var to expr");
	x = new Variable(Symbol.intern("X"));
	e = new Expression();
	e.add(Symbol.intern("P"));
	e.add(Symbol.intern("A"));
	Expression e2 = new Expression();
	e2.add(Symbol.intern("F"));
	e2.add(Symbol.intern("B"));
	e.add(e2);
	test(x, e);

	System.out.println("Variable and Expression (using var) -> fail");
	x = new Variable(Symbol.intern("X"));
	e = new Expression();
	e.add(Symbol.intern("P"));
	e.add(Symbol.intern("A"));
	e.add(x);
	test(x, e);

	System.out.println("Variable and nested Expression (not using var) -> bind var to expr");
	x = new Variable(Symbol.intern("X"));
	e = new Expression();
	e.add(Symbol.intern("P"));
	e.add(Symbol.intern("A"));
	e2 = new Expression();
	e2.add(Symbol.intern("F"));
	e2.add(x);
	e.add(e2);
	test(x, e);
    }

    static void test(Unifiable x, Unifiable y) {
	BindingSet bindings = new BindingSet();
	boolean result;
	System.out.println("  x=" + x + ", y=" + y);
	result = x.unifyWith(y, bindings);
	System.out.println("  result=" + result + ", bindings=" + bindings);
	System.out.println();
    }
}
