/*
 * Debug.java
 *
 * George Ferguson, ferguson@cs.rochester.edu, 18 Apr 2002
 * Time-stamp: <Fri May 23 11:27:49 EDT 2003 ferguson>
 */

/**
 * Debugging routines.
 */
public class Debug {
    /**
     * Print a warning message (unconditionally).
     */
    public static void warn(String msg) {
	System.err.println("warning: " + msg);
    }
    /**
     * Flag whether to print trace messages.
     */
    static boolean traceEnabled = true;
    /**
     * Specify whether to print trace messages.
     */
    public static void setTracingEnabled(boolean flag) {
	traceEnabled = flag;
    }
    /**
     * Print a trace message (if these are enabled).
     */
    public static void trace(String msg) {
	if (traceEnabled) {
	    System.err.println(msg);
	}
    }
    /**
     * Flag whether to print IO debug messages.
     */
    static boolean debugIOEnabled = false;
    /**
     * Specify whether to print debug messages.
     */
    public static void setDebugIO(boolean flag) {
	debugIOEnabled = flag;
    }
    /**
     * Debug IO operations
     */
    public static void debugIO(String msg) {
	if (debugIOEnabled) {
	    System.err.println("io: " + msg);
	}
    }
    /**
     * Flag whether to print (unspecified) debug messages.
     */
    static boolean debugEnabled = false;
    /**
     * Specify whether to print debug messages.
     */
    public static void setDebug(boolean flag) {
	debugEnabled = flag;
	debugIOEnabled = flag;
    }
    /**
     * Print a debug message (if these are enabled).
     */
    public static void debug(String msg) {
	if (debugEnabled) {
	    System.err.println(msg);
	}
    }
}
