/*
 * LinkedListSet.java
 *
 * George Ferguson, ferguson@cs.rochester.edu, 15 Apr 2002
 * Time-stamp: <Wed May 14 12:08:21 EDT 2003 ferguson>
 *
 */

import java.util.AbstractSet;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.NoSuchElementException;
import java.util.Set;

/**
 * LinkedListSet implements the Set interface using a LinkedList to
 * store the elements of the set. This will/should/might have less
 * overhead than a HashSet for small sets.
 * <BR>
 * Implementation Note: Extending AbstractSet allows us to get by with
 * specifying the minimal number of additional methods (namely size(),
 * iterator(), and add()).  It might be faster to implement some of
 * the other operations, but the default implementations are likely to
 * be just as good for this set backed by a LinkedList (e.g.,
 * contains() is almost certainly implemented by using the iterator()
 * to look for the element, which is essentially equivalent to our
 * calling contains() on the backing LinkedList.
 */
public class LinkedListSet extends AbstractSet implements Set {
    /**
     * LinkedList holding the elements in this set.
     */
    LinkedList elements;
    /**
     * Creates a new empty LinkedListSet.
     * This constructor is required by the conventions of the Collection
     * interface.
     */
    public LinkedListSet() {
	elements = new LinkedList();
    }
    /**
     * Creates a new LinkedListSet with the same contents as the given
     * Collection.
     * This constructor is required by the conventions of the Collection
     * interface.
     */
    public LinkedListSet(Collection c) {
	elements = new LinkedList(c);
    }
    /**
     * Returns the number of elements in this set.
     */
    public int size() {
	return elements.size();
    }
    /**
     * Returns an iterator over the elements contained in this set.
     */
    public Iterator iterator() {
	return elements.iterator();
    }
    /**
     * Ensures that this collection contains the specified element
     * Returns true if the set changed as a result of the
     * call. Returns false if the set already contains the specified
     * element.
     */
    public boolean add(Object o) {
	if (elements.contains(o)) {
	    return false;
	} else {
	    elements.add(o);
	    return true;
	}
    }
}
