;;;;
;;;; lisp2xml.lisp: Translate James' lexicon and grammar files to XML
;;;;
;;;; George Ferguson, ferguson@cs.rochester.edu, 22 May 2003
;;;; Time-stamp: <Fri May 23 10:36:36 EDT 2003 ferguson>
;;;;

(defun lexicon2xml (lexicon id)
  (format t "<?xml version=\"1.0\" encoding=\"us-ascii\"?>~%~%")
  (format t "<!DOCTYPE lexicon SYSTEM \"lexicon.dtd\">~%~%")
  (format t "<lexicon id=\"~A\">~%~%" id)
  (format t "<description>~%~%")
  (format t "</description>~%~%")
  (mapc #'entry2xml lexicon)
  (format t "</lexicon>~%~%---cut---~%~%"))

(defun entry2xml (entry)
  (format t "<word id=\"~A\">~%" (car entry))
  (format t "  <sense>~%")
  (format t "    <category>~A</category>~%" (car (second entry)))
  (features2xml (cdr (second entry)))
  (format t "  </sense>~%")
  (format t "</word>~%~%"))

(defun features2xml (feats)
  (mapc #'(lambda (feat)
	    (let ((name (car feat))
		  (value (cadr feat)))
	      (when (and (listp value) (eq (car value) '?))
		(setq value
		      (cons (intern (format nil "?~A" (cadr value)))
			    (cddr value))))
	      (format t "    <~(~A~)>" name)
	      (if (symbolp value)
		  (format t "~A" value)
		(format t "~{~A~^ ~}" value))
	      (format t "</~(~A~)>~%" name)))
	feats))

(defun grammar2xml (grammar id)
  (format t "<?xml version=\"1.0\" encoding=\"us-ascii\"?>~%~%")
  (format t "<!DOCTYPE grammar SYSTEM \"grammar.dtd\">~%~%")
  (format t "<grammar id=\"~A\">~%~%" id)
  (format t "<description>~%~%")
  (format t "</description>~%~%")
  (mapc #'rule2xml grammar)
  (format t "</grammar>~%~%---cut---~%~%"))

(defun rule2xml (rule)
  (if (eq (car rule) 'headfeatures)
      (headfeatures2xml (cdr rule))
    (let ((lhs (first rule))
	  (id (second rule))
	  (rhs (cddr rule)))
      (format t "<rule id=\"~A\">~%" id)
      (constit2xml lhs)
      (format t "  <!-- -->~%")
      (mapc #'constit2xml rhs)
      (format t "</rule>~%~%"))))

(defun constit2xml (constit &optional (head nil))
  (if (eq (car constit) 'head)
      (constit2xml (second constit) t)
    (let ((cat (car constit))
	  (feats (cdr constit)))
      (format t "  <~A~:[~; head=\"T\"~]~:[/~;~]>~%" cat head feats)
      (features2xml feats)
      (if feats
	  (format t "  </~A>~%" cat)))))

(defun headfeatures2xml (feats)
  (format t "<headfeatures>~%")
  (mapc #'(lambda (feat)
	    (format t "  <~A>" (car feat))
	    (format t "~{~(~A~)~^ ~}" (cdr feat))
	    (format t "</~A>~%" (car feat)))
	feats)
  (format t "</headfeatures>~%~%"))
  
(load "../lisp/Grammars/Chapter4")
(grammar2xml *grammar4-5* "grammar-4.5")
(lexicon2xml *lexicon4-6* "lexicon-4.6")
(grammar2xml *grammar4-7* "grammar-4.7")

(load "../lisp/Grammars/Chapter5")
(lexicon2xml *lexicon5-2* "lexicon-5.2")
(grammar2xml *grammar5-3* "grammar-5.3")
(lexicon2xml *lexicon5-6* "lexicon-5.6")
(lexicon2xml *lexicon-additions* "lexicon-additions-5")
(grammar2xml *grammar5-7* "grammar-5.7")
(grammar2xml *grammar5-8* "grammar-5.8")
(grammar2xml *grammar-RelClause* "grammar-rel-clauses-5")
